@@ -28,7 +28,7 @@ Settings are passed across processes via filesystem, and a copy of the settings
 each run and subject is left under
 ``<output_dir>/sub-<participant_id>/log/<run_unique_id>/mriqc.toml``.
 Settings are stored using :abbr:`ToML (Tom's Markup Language)`.
-The module has a :py:func:`~mriqc.config.to_filename` function to allow writting out
+The module has a :py:func:`~mriqc.config.to_filename` function to allow writing out
 the settings to hard disk in *ToML* format, which looks like:
 
 .. literalinclude:: ../mriqc/data/config-example.toml
@@ -363,7 +363,7 @@ class execution(_Config):
     echo_id = None
     """Select a particular echo for multi-echo EPI datasets."""
     float32 = True
-    """Cast the input data to float32 if it's represented whith higher precision."""
+    """Cast the input data to float32 if it's represented with higher precision."""
     layout = None
     """A :py:class:`~bids.layout.BIDSLayout` object, see :py:func:`init`."""
     log_dir = None
@@ -374,6 +374,8 @@ class execution(_Config):
     """Filter input dataset by MRI type."""
     no_sub = False
     """Turn off submission of anonymized quality metrics to Web API."""
+    notrack = False
+    """Disable the sharing of usage information with developers."""
     output_dir = None
     """Folder where derivatives will be stored."""
     participant_label = None
@@ -430,6 +432,26 @@ class execution(_Config):
             from bids.layout.index import BIDSLayoutIndexer
             from bids.layout import BIDSLayout
 
+            ignore_paths = [
+                # Ignore folders at the top if they don't start with /sub-<label>/
+                re.compile(r"^(?!/sub-[a-zA-Z0-9]+)"),
+                # Ignore all modality subfolders, except for func/ or anat/
+                re.compile(
+                    r"^/sub-[a-zA-Z0-9]+(/ses-[a-zA-Z0-9]+)?/"
+                    r"(beh|dwi|fmap|pet|perf|meg|eeg|ieeg|micr|nirs)"
+                ),
+                # Ignore all files, except for the supported modalities
+                re.compile(r"^.+(?<!(_T1w|_T2w|bold))\.(json|nii|nii\.gz)$"),
+            ]
+
+            if cls.participant_label:
+                # If we know participant labels, ignore all other
+                ignore_paths[0] = re.compile(
+                    r"^(?!/sub-("
+                    + "|".join(cls.participant_label)
+                    + r"))"
+                )
+
             _db_path = cls.bids_database_dir or (
                 cls.work_dir / cls.run_uuid / "bids_db"
             )
@@ -438,30 +460,7 @@ class execution(_Config):
             # Recommended after PyBIDS 12.1
             _indexer = BIDSLayoutIndexer(
                 validate=False,
-                ignore=(
-                    "code",
-                    "stimuli",
-                    "sourcedata",
-                    "models",
-                    "derivatives",
-                    "scripts",
-                    re.compile(r"^\."),
-                    # Exclude modalities and contrasts ignored by MRIQC (doesn't know how to QC)
-                    re.compile(
-                        r"sub-[a-zA-Z0-9]+(/ses-[a-zA-Z0-9]+)?/(dwi|fmap|perf)/"
-                    ),
-                    re.compile(
-                        r"sub-[a-zA-Z0-9]+(/ses-[a-zA-Z0-9]+)?/anat/.*_"
-                        r"(PDw|T2starw|FLAIR|inplaneT1|inplaneT2|PDT2|angio|T2star"
-                        r"|FLASH|PD|T1map|T2map|T2starmap|R1map|R2map|R2starmap|PDmap"
-                        r"|MTRmap|MTsat|UNIT1|T1rho|MWFmap|MTVmap|PDT2map|Chimap"
-                        r"|S0map|M0map|defacemask|MESE|MEGRE|VFA|IRT1|MP2RAGE|MPM|MTS|MTR)\."
-                    ),
-                    re.compile(
-                        r"sub-[a-zA-Z0-9]+(/ses-[a-zA-Z0-9]+)?/func/.*"
-                        r"_(cbv|sbref|phase|events|physio|stim)\."
-                    ),
-                ),
+                ignore=ignore_paths,
             )
             cls._layout = BIDSLayout(
                 str(cls.bids_dir),
